
TODO: TODO_55_51_89_92: review and update `args_context`

The concept of `args_context` was never clarified.

What is even `args_context`? It is meaningless (or means many things).
Also describe or merged `assigned_context` vs `args_context`.

Now, it is old and may require rethink or complete removal.

See also:
*   FS_62_25_92_06 manipulating `assigned_context`
